import os


def get_log_stream_html(
    title: str = "Log streamer", ws_url: str = None
) -> str:
    path = os.path.abspath(
        os.path.join(__file__, os.pardir, "LogStreaming.html")
    )
    with open(path, encoding="utf-8") as file:
        html = file.read()

    html = html.replace("{{ENV_TITLE}}", title)

    return html



import os
from datetime import datetime, timedelta

from MeowthLogger.constants import DEFAULT_LOGGING_FILENAME, FOLDER_DATE_FORMAT
from MeowthLogger.utilities.abstractions import DateNameFile


class LogFile(DateNameFile):
    def __init__(self, day: datetime, name: str, path: str) -> None:
        self.path = path
        self.name = name
        hour = int(name[:2])
        self.date = day + timedelta(hours=hour)

    def read(self) -> bytes:
        with open(self.path_join, "rb") as file:
            return file.read()


class RootLogFile(LogFile):
    def __init__(self, name: str, path: str) -> None:
        self.name = name
        self.path = path


class LogDirectory(DateNameFile):
    name: str
    date: datetime

    files: list[LogFile]

    def __init__(self, name: str, path: str) -> None:
        self.name = name
        self.date = datetime.strptime(
            name,
            FOLDER_DATE_FORMAT,
        )
        self.path = path
        self.files = self.get_files()

    def get_files(self) -> list[LogFile]:
        files_list = os.listdir(self.path_join)

        return sorted(
            LogFile(self.date, file_name, self.path_join)
            for file_name in files_list
        )

    def read(self) -> bytes:
        return b"".join([file.read() for file in self.files])


class DirectoriesTree:
    """Tree of logfiles directory
    Used for sorting files by dates
    """

    dirs: list[LogDirectory]

    def __init__(self, path: str) -> None:
        dir_list = os.listdir(path)

        if DEFAULT_LOGGING_FILENAME in dir_list:
            dir_list.remove(DEFAULT_LOGGING_FILENAME)

        self.dirs = sorted(
            [LogDirectory(dir_name, path) for dir_name in dir_list]
        )

    def sort_files(self, date_from: datetime, date_to: datetime) -> None:
        """Sorting self all files by requested dates"""

        if not self.dirs:
            return

        # Filter directories list
        self.dirs = list(
            filter(
                lambda dir: dir.date > date_from - timedelta(days=1)
                and dir.date < date_to,
                self.dirs,
            )
        )

        if self.dirs:
            # Sort files for first directory
            self.dirs[0].files = list(
                filter(
                    lambda file: file.date > date_from - timedelta(hours=1),
                    self.dirs[0].files,
                )
            )

            # Sort files for last directory
            self.dirs[-1].files = list(
                filter(lambda file: file.date < date_to, self.dirs[-1].files)
            )



import re
from datetime import datetime, timedelta

from MeowthLogger.constants import (
    LOGSTRING_DATE_FORMAT,
    LOGSTRING_DATE_REGEXP,
    REQUEST_DATESTRING_FORMAT,
)
from MeowthLogger.errors import NotDateLogString, NotValidLogsDateFormat


def convert_request_datestring(request_date_string: str) -> datetime:
    """Converting reques string date to datetime object"""
    try:
        d = datetime.strptime(request_date_string, REQUEST_DATESTRING_FORMAT)
        return d
    except:
        raise NotValidLogsDateFormat


def set_null_minutes(date: datetime) -> datetime:
    """Preparing date for get datetime hour object"""
    return date - timedelta(
        minutes=date.minute, seconds=date.second, microseconds=date.microsecond
    )


def date_from_logstring(log_string: str) -> datetime:
    """Preparing date in logstring date format to datetime object"""
    date_pattern = re.compile(LOGSTRING_DATE_REGEXP)
    match = date_pattern.search(log_string)

    if not match:
        raise NotDateLogString

    return datetime.strptime(match.group(1), LOGSTRING_DATE_FORMAT)



from abc import ABC

from .abstract import AbstractLoggerConfig
from .utils import ConfigLogger


class UvicornLogger(AbstractLoggerConfig, ABC):
    def _use_uvicorn(self) -> None:
        self.loggers.append(
            ConfigLogger(
                name="uvicorn.access",
                level="INFO",
                handlers=self.handlers,
                propagate=False,
            )
        )

        self.loggers.append(
            ConfigLogger(
                name="uvicorn.error",
                level="INFO",
                handlers=self.handlers,
                propagate=False,
            )
        )



import asyncio

from fastapi import FastAPI
from uvicorn import Config, Server

from MeowthLogger import Logger
from MeowthLogger.utilities.fastapi.log_stream import StreamManager
from MeowthLogger.utilities.fastapi.views import get_log_stream_views_router


loop = asyncio.new_event_loop()
managa = StreamManager(loop)
api = FastAPI()


@api.get("/")
async def home() -> dict[str, bool]:
    return {"ok": True}


logger = Logger(use_files=True, use_uvicorn=True, stream=managa)
logger.info("TEST")


api.include_router(get_log_stream_views_router(logger))


config = Config(app=api, host="0.0.0.0", log_config=None)

server = Server(config)


async def main() -> None:
    await server.serve()


if __name__ == "__main__":
    asyncio.run(main())



from ..settings import LoggerSettings
from .abstract import AbstractLoggerConfig
from .console import ConsoleLogger
from .file import FileLogger
from .stream import StreamLogger
from .uvicorn import UvicornLogger


class MainLoggerConfig(
    FileLogger,
    ConsoleLogger,
    UvicornLogger,
    StreamLogger,
    AbstractLoggerConfig,
):

    def __init__(
        self,
        settings: LoggerSettings,
        version: int = 1,
    ) -> None:
        super().__init__(settings, version)

        self._use_console()

        if settings.use_files:
            self._use_files()

        if settings.use_uvicorn:
            self._use_uvicorn()

        if settings.stream:
            self._use_stream()



import logging
import os
import time
from datetime import datetime

from MeowthLogger.constants import DEFAULT_FORMATTER


class AbstractFormatter(logging.Formatter):
    def __init__(self) -> None:
        logging.Formatter.__init__(self, "")

    def format(self, record: str) -> str:
        return self.prepare_log_string(
            datetime=time.strftime(
                self.default_time_format, self.converter(record.created)
            ),
            levelname=self.prepare_levelname(record.levelno),
            filename=record.pathname.replace(os.path.abspath(""), "."),
            line=str(record.lineno),
            message=record.getMessage(),
        )

    def prepare_log_string(
        self,
        datetime: datetime,
        levelname: str,
        filename: str,
        line: int,
        message: str,
    ) -> str:
        return DEFAULT_FORMATTER.format(
            datetime=datetime,
            levelname=levelname,
            filename=filename,
            line=line,
            message=message,
        )



from abc import ABC

from MeowthLogger.utilities.abstractions import Dictable

from ..settings import LoggerSettings
from .utils import ConfigFormatter, ConfigHandler, ConfigLogger, ConfigRoot


class AbstractLoggerConfig(Dictable, ABC):
    version: int
    settings: LoggerSettings

    formatters: list[ConfigFormatter]
    handlers: list[ConfigHandler]
    loggers: list[ConfigLogger]

    root: ConfigRoot

    def __init__(
        self,
        settings: LoggerSettings,
        version: int,
    ) -> None:
        self.settings = settings
        self.version = version

        self.handlers = []
        self.loggers = []
        self.formatters = []

    def json(self) -> dict:
        return {
            "version": self.version,
            "formatters": {
                formatter.name: formatter.json()
                for formatter in self.formatters
            },
            "handlers": {
                handler.name: handler.json() for handler in self.handlers
            },
            "loggers": {logger.name: logger.json() for logger in self.loggers},
            "root": ConfigRoot(
                self.settings.logger_level, self.handlers
            ).json(),
        }
